@@ -497,7 +497,7 @@ class Repository(object):
                     self.run(self.easy_install_path + ['-q', self.pypi])
             elif preinstall: 
                 if not os.path.exists(dir):
-                    self.run(self.easy_install_path + ['-q', '--editable', '--build-directory', '.', self.pypi], dir=os.path.dirname(dir))
+                    self.run(self.easy_install_path + ['-q', '--exclude-scripts', '--always-copy', '--editable', '--build-directory', '.', self.pypi], dir=os.path.dirname(dir))
         except OSError, err:
             print ""
             print "Error installing package %s with easy_install" % self.name
@@ -520,7 +520,7 @@ class Repository(object):
 
 if sys.platform.startswith('win'):
     if not is_jython:
-        Repository.python += '.exe'
+        Repository.python += 'w.exe'
     Repository.svn += '.exe'
 
 
@@ -1015,6 +1015,8 @@ class Installer(object):
             bindir = join(self.abshome_dir,"bin")
         if is_jython:
             Repository.python = os.path.abspath(join(bindir, 'jython.bat'))
+        elif sys.platform.startswith('win'):
+            Repository.python = os.path.abspath(join(bindir, 'pythonw'))
         else:
             Repository.python = os.path.abspath(join(bindir, 'python'))
         if os.path.exists(os.path.abspath(join(bindir, 'easy_install'))):
@@ -1053,6 +1055,10 @@ class Installer(object):
                 else:
                     pkg.install_release(dir=srcdir, preinstall=options.preinstall, offline=options.offline)
         #
+        # Localize DOS cmd files
+        #
+        self.localize_cmd_files(self.abshome_dir, options.localize)
+        #
         # Copy the <env>/Scripts/* files into <env>/bin
         #
         if os.path.exists(self.abshome_dir+os.sep+"Scripts"):
@@ -1061,10 +1067,6 @@ class Installer(object):
             for file in glob.glob(self.abshome_dir+os.sep+"Scripts"+os.sep+"*"):
                 shutil.copy(file, self.abshome_dir+os.sep+"bin")
         #
-        # Localize DOS cmd files
-        #
-        self.localize_cmd_files(self.abshome_dir, options.localize)
-        #
         # Misc notifications
         #
         if not options.update:
@@ -1082,12 +1084,20 @@ class Installer(object):
         """
         if not (sys.platform.startswith('win') or force_localization):
             return
+        if os.path.exists(dir+os.sep+"Scripts"):
+            bindir = 'Scripts'
+        else:
+            bindir = 'bin'
         for file in self.cmd_files:
-            INPUT = open(join(dir,'bin',file), 'r')
+            fname = join(dir,bindir,file)
+            if not os.path.exists(fname):
+                print "WARNING: Problem while localizing file '%s'.  This file is missing" % fname
+                continue
+            INPUT = open(fname, 'r')
             content = "".join(INPUT.readlines())
             INPUT.close()
             content = content.replace('__VIRTUAL_ENV__',dir)
-            OUTPUT = open(join(dir,'bin',file), 'w')
+            OUTPUT = open(fname, 'w')
             OUTPUT.write(content)
             OUTPUT.close()
 
